# -----------------------------------------------------------------------------
#  Copyright (c) The Jupyter Development Team
#
#  Distributed under the terms of the BSD License.  The full license is in
#  the file LICENSE, distributed as part of this software.
# -----------------------------------------------------------------------------
import sys

from jupyter_client import localinterfaces


def test_load_ips():
    # Override the machinery that skips it if it was called before
    localinterfaces._load_ips.called = False  # type:ignore[attr-defined]

    # Just check this doesn't error
    localinterfaces._load_ips(suppress_exceptions=False)

    localinterfaces.is_local_ip('8.8.8.8')
    localinterfaces.is_public_ip('127.0.0.1')
    ips = localinterfaces.local_ips()
    assert '127.0.0.1' in ips

    localinterfaces._load_ips_gethostbyname()
    localinterfaces._load_ips_dumb()

    if sys.platform == 'linux':
        localinterfaces._load_ips_ip()
        localinterfaces._load_ips_ifconfig()



import socket

import pytest

from jupyter_client.ssh.tunnel import open_tunnel, select_random_ports


def test_random_ports():
    for _ in range(4096):
        ports = select_random_ports(10)
        assert len(ports) == 10
        for p in ports:
            assert ports.count(p) == 1


def test_open_tunnel():
    with pytest.raises((RuntimeError, socket.error)):
        open_tunnel("tcp://localhost:1234", "does.not.exist")
